# Warning: this file is auto-generated. Do not edit.

VERSION_1_0 = 1
MIN_COMPOSITION_LAYERS_SUPPORTED = 16
NULL_HANDLE = 0
NULL_SYSTEM_ID = 0
NULL_PATH = 0
NO_DURATION = 0
INFINITE_DURATION = 0x7fffffffffffffff
MIN_HAPTIC_DURATION = -1
FREQUENCY_UNSPECIFIED = 0
EXTENSION_ENUM_BASE = 1000000000
EXTENSION_ENUM_STRIDE = 1000
TRUE = 1
FALSE = 0
MAX_EXTENSION_NAME_SIZE = 128
MAX_API_LAYER_NAME_SIZE = 256
MAX_API_LAYER_DESCRIPTION_SIZE = 256
MAX_SYSTEM_NAME_SIZE = 256
MAX_APPLICATION_NAME_SIZE = 128
MAX_ENGINE_NAME_SIZE = 128
MAX_RUNTIME_NAME_SIZE = 128
MAX_PATH_LENGTH = 256
MAX_STRUCTURE_NAME_SIZE = 64
MAX_RESULT_STRING_SIZE = 64
MAX_ACTION_SET_NAME_SIZE = 64
MAX_LOCALIZED_ACTION_SET_NAME_SIZE = 128
MAX_ACTION_NAME_SIZE = 64
MAX_LOCALIZED_ACTION_NAME_SIZE = 128
VERSION_1_1 = 1
UUID_SIZE = 16
KHR_composition_layer_cube = 1
KHR_composition_layer_cube_SPEC_VERSION = 8
KHR_COMPOSITION_LAYER_CUBE_EXTENSION_NAME = "XR_KHR_composition_layer_cube"
KHR_composition_layer_depth = 1
KHR_composition_layer_depth_SPEC_VERSION = 6
KHR_COMPOSITION_LAYER_DEPTH_EXTENSION_NAME = "XR_KHR_composition_layer_depth"
KHR_composition_layer_cylinder = 1
KHR_composition_layer_cylinder_SPEC_VERSION = 4
KHR_COMPOSITION_LAYER_CYLINDER_EXTENSION_NAME = "XR_KHR_composition_layer_cylinder"
KHR_composition_layer_equirect = 1
KHR_composition_layer_equirect_SPEC_VERSION = 3
KHR_COMPOSITION_LAYER_EQUIRECT_EXTENSION_NAME = "XR_KHR_composition_layer_equirect"
KHR_visibility_mask = 1
KHR_visibility_mask_SPEC_VERSION = 2
KHR_VISIBILITY_MASK_EXTENSION_NAME = "XR_KHR_visibility_mask"
KHR_composition_layer_color_scale_bias = 1
KHR_composition_layer_color_scale_bias_SPEC_VERSION = 5
KHR_COMPOSITION_LAYER_COLOR_SCALE_BIAS_EXTENSION_NAME = "XR_KHR_composition_layer_color_scale_bias"
KHR_loader_init = 1
KHR_loader_init_SPEC_VERSION = 2
KHR_LOADER_INIT_EXTENSION_NAME = "XR_KHR_loader_init"
KHR_composition_layer_equirect2 = 1
KHR_composition_layer_equirect2_SPEC_VERSION = 1
KHR_COMPOSITION_LAYER_EQUIRECT2_EXTENSION_NAME = "XR_KHR_composition_layer_equirect2"
KHR_binding_modification = 1
KHR_binding_modification_SPEC_VERSION = 1
KHR_BINDING_MODIFICATION_EXTENSION_NAME = "XR_KHR_binding_modification"
KHR_extended_struct_name_lengths = 1
KHR_extended_struct_name_lengths_SPEC_VERSION = 1
KHR_EXTENDED_STRUCT_NAME_LENGTHS_EXTENSION_NAME = "XR_KHR_extended_struct_name_lengths"
MAX_STRUCTURE_NAME_SIZE_EXTENDED_KHR = 256
KHR_swapchain_usage_input_attachment_bit = 1
KHR_swapchain_usage_input_attachment_bit_SPEC_VERSION = 3
KHR_SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_EXTENSION_NAME = "XR_KHR_swapchain_usage_input_attachment_bit"
KHR_locate_spaces = 1
KHR_locate_spaces_SPEC_VERSION = 1
KHR_LOCATE_SPACES_EXTENSION_NAME = "XR_KHR_locate_spaces"
KHR_maintenance1 = 1
KHR_maintenance1_SPEC_VERSION = 1
KHR_MAINTENANCE1_EXTENSION_NAME = "XR_KHR_maintenance1"
EXT_performance_settings = 1
EXT_performance_settings_SPEC_VERSION = 4
EXT_PERFORMANCE_SETTINGS_EXTENSION_NAME = "XR_EXT_performance_settings"
EXT_thermal_query = 1
EXT_thermal_query_SPEC_VERSION = 2
EXT_THERMAL_QUERY_EXTENSION_NAME = "XR_EXT_thermal_query"
EXT_debug_utils = 1
EXT_debug_utils_SPEC_VERSION = 5
EXT_DEBUG_UTILS_EXTENSION_NAME = "XR_EXT_debug_utils"
EXT_eye_gaze_interaction = 1
EXT_eye_gaze_interaction_SPEC_VERSION = 2
EXT_EYE_GAZE_INTERACTION_EXTENSION_NAME = "XR_EXT_eye_gaze_interaction"
EXTX_overlay = 1
EXTX_overlay_SPEC_VERSION = 5
EXTX_OVERLAY_EXTENSION_NAME = "XR_EXTX_overlay"
VARJO_quad_views = 1
VARJO_quad_views_SPEC_VERSION = 2
VARJO_QUAD_VIEWS_EXTENSION_NAME = "XR_VARJO_quad_views"
MSFT_unbounded_reference_space = 1
MSFT_unbounded_reference_space_SPEC_VERSION = 1
MSFT_UNBOUNDED_REFERENCE_SPACE_EXTENSION_NAME = "XR_MSFT_unbounded_reference_space"
MSFT_spatial_anchor = 1
MSFT_spatial_anchor_SPEC_VERSION = 2
MSFT_SPATIAL_ANCHOR_EXTENSION_NAME = "XR_MSFT_spatial_anchor"
FB_composition_layer_image_layout = 1
FB_composition_layer_image_layout_SPEC_VERSION = 1
FB_COMPOSITION_LAYER_IMAGE_LAYOUT_EXTENSION_NAME = "XR_FB_composition_layer_image_layout"
FB_composition_layer_alpha_blend = 1
FB_composition_layer_alpha_blend_SPEC_VERSION = 3
FB_COMPOSITION_LAYER_ALPHA_BLEND_EXTENSION_NAME = "XR_FB_composition_layer_alpha_blend"
MND_headless = 1
MND_headless_SPEC_VERSION = 2
MND_HEADLESS_EXTENSION_NAME = "XR_MND_headless"
OCULUS_android_session_state_enable = 1
OCULUS_android_session_state_enable_SPEC_VERSION = 1
OCULUS_ANDROID_SESSION_STATE_ENABLE_EXTENSION_NAME = "XR_OCULUS_android_session_state_enable"
EXT_view_configuration_depth_range = 1
EXT_view_configuration_depth_range_SPEC_VERSION = 1
EXT_VIEW_CONFIGURATION_DEPTH_RANGE_EXTENSION_NAME = "XR_EXT_view_configuration_depth_range"
EXT_conformance_automation = 1
EXT_conformance_automation_SPEC_VERSION = 3
EXT_CONFORMANCE_AUTOMATION_EXTENSION_NAME = "XR_EXT_conformance_automation"
MSFT_spatial_graph_bridge = 1
GUID_SIZE_MSFT = 16
MSFT_spatial_graph_bridge_SPEC_VERSION = 2
MSFT_SPATIAL_GRAPH_BRIDGE_EXTENSION_NAME = "XR_MSFT_spatial_graph_bridge"
MSFT_hand_interaction = 1
MSFT_hand_interaction_SPEC_VERSION = 1
MSFT_HAND_INTERACTION_EXTENSION_NAME = "XR_MSFT_hand_interaction"
EXT_hand_tracking = 1
HAND_JOINT_COUNT_EXT = 26
EXT_hand_tracking_SPEC_VERSION = 4
EXT_HAND_TRACKING_EXTENSION_NAME = "XR_EXT_hand_tracking"
MSFT_hand_tracking_mesh = 1
MSFT_hand_tracking_mesh_SPEC_VERSION = 4
MSFT_HAND_TRACKING_MESH_EXTENSION_NAME = "XR_MSFT_hand_tracking_mesh"
MSFT_secondary_view_configuration = 1
MSFT_secondary_view_configuration_SPEC_VERSION = 1
MSFT_SECONDARY_VIEW_CONFIGURATION_EXTENSION_NAME = "XR_MSFT_secondary_view_configuration"
MSFT_first_person_observer = 1
MSFT_first_person_observer_SPEC_VERSION = 1
MSFT_FIRST_PERSON_OBSERVER_EXTENSION_NAME = "XR_MSFT_first_person_observer"
MSFT_controller_model = 1
NULL_CONTROLLER_MODEL_KEY_MSFT = 0
MAX_CONTROLLER_MODEL_NODE_NAME_SIZE_MSFT = 64
MSFT_controller_model_SPEC_VERSION = 2
MSFT_CONTROLLER_MODEL_EXTENSION_NAME = "XR_MSFT_controller_model"
EXT_win32_appcontainer_compatible = 1
EXT_win32_appcontainer_compatible_SPEC_VERSION = 1
EXT_WIN32_APPCONTAINER_COMPATIBLE_EXTENSION_NAME = "XR_EXT_win32_appcontainer_compatible"
EPIC_view_configuration_fov = 1
EPIC_view_configuration_fov_SPEC_VERSION = 2
EPIC_VIEW_CONFIGURATION_FOV_EXTENSION_NAME = "XR_EPIC_view_configuration_fov"
MSFT_composition_layer_reprojection = 1
MSFT_composition_layer_reprojection_SPEC_VERSION = 1
MSFT_COMPOSITION_LAYER_REPROJECTION_EXTENSION_NAME = "XR_MSFT_composition_layer_reprojection"
HUAWEI_controller_interaction = 1
HUAWEI_controller_interaction_SPEC_VERSION = 1
HUAWEI_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_HUAWEI_controller_interaction"
FB_swapchain_update_state = 1
FB_swapchain_update_state_SPEC_VERSION = 3
FB_SWAPCHAIN_UPDATE_STATE_EXTENSION_NAME = "XR_FB_swapchain_update_state"
FB_composition_layer_secure_content = 1
FB_composition_layer_secure_content_SPEC_VERSION = 1
FB_COMPOSITION_LAYER_SECURE_CONTENT_EXTENSION_NAME = "XR_FB_composition_layer_secure_content"
FB_body_tracking = 1
FB_body_tracking_SPEC_VERSION = 1
FB_BODY_TRACKING_EXTENSION_NAME = "XR_FB_body_tracking"
EXT_dpad_binding = 1
EXT_dpad_binding_SPEC_VERSION = 1
EXT_DPAD_BINDING_EXTENSION_NAME = "XR_EXT_dpad_binding"
VALVE_analog_threshold = 1
VALVE_analog_threshold_SPEC_VERSION = 2
VALVE_ANALOG_THRESHOLD_EXTENSION_NAME = "XR_VALVE_analog_threshold"
EXT_hand_joints_motion_range = 1
EXT_hand_joints_motion_range_SPEC_VERSION = 1
EXT_HAND_JOINTS_MOTION_RANGE_EXTENSION_NAME = "XR_EXT_hand_joints_motion_range"
EXT_samsung_odyssey_controller = 1
EXT_samsung_odyssey_controller_SPEC_VERSION = 1
EXT_SAMSUNG_ODYSSEY_CONTROLLER_EXTENSION_NAME = "XR_EXT_samsung_odyssey_controller"
EXT_hp_mixed_reality_controller = 1
EXT_hp_mixed_reality_controller_SPEC_VERSION = 1
EXT_HP_MIXED_REALITY_CONTROLLER_EXTENSION_NAME = "XR_EXT_hp_mixed_reality_controller"
MND_swapchain_usage_input_attachment_bit = 1
MND_swapchain_usage_input_attachment_bit_SPEC_VERSION = 2
MND_SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_EXTENSION_NAME = "XR_MND_swapchain_usage_input_attachment_bit"
MSFT_scene_understanding = 1
MSFT_scene_understanding_SPEC_VERSION = 2
MSFT_SCENE_UNDERSTANDING_EXTENSION_NAME = "XR_MSFT_scene_understanding"
MSFT_scene_understanding_serialization = 1
MSFT_scene_understanding_serialization_SPEC_VERSION = 2
MSFT_SCENE_UNDERSTANDING_SERIALIZATION_EXTENSION_NAME = "XR_MSFT_scene_understanding_serialization"
FB_display_refresh_rate = 1
FB_display_refresh_rate_SPEC_VERSION = 1
FB_DISPLAY_REFRESH_RATE_EXTENSION_NAME = "XR_FB_display_refresh_rate"
HTC_vive_cosmos_controller_interaction = 1
HTC_vive_cosmos_controller_interaction_SPEC_VERSION = 1
HTC_VIVE_COSMOS_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_HTC_vive_cosmos_controller_interaction"
HTCX_vive_tracker_interaction = 1
HTCX_vive_tracker_interaction_SPEC_VERSION = 3
HTCX_VIVE_TRACKER_INTERACTION_EXTENSION_NAME = "XR_HTCX_vive_tracker_interaction"
HTC_facial_tracking = 1
FACIAL_EXPRESSION_EYE_COUNT_HTC = 14
FACIAL_EXPRESSION_LIP_COUNT_HTC = 37
HTC_facial_tracking_SPEC_VERSION = 3
HTC_FACIAL_TRACKING_EXTENSION_NAME = "XR_HTC_facial_tracking"
HTC_vive_focus3_controller_interaction = 1
HTC_vive_focus3_controller_interaction_SPEC_VERSION = 2
HTC_VIVE_FOCUS3_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_HTC_vive_focus3_controller_interaction"
HTC_hand_interaction = 1
HTC_hand_interaction_SPEC_VERSION = 1
HTC_HAND_INTERACTION_EXTENSION_NAME = "XR_HTC_hand_interaction"
HTC_vive_wrist_tracker_interaction = 1
HTC_vive_wrist_tracker_interaction_SPEC_VERSION = 1
HTC_VIVE_WRIST_TRACKER_INTERACTION_EXTENSION_NAME = "XR_HTC_vive_wrist_tracker_interaction"
FB_color_space = 1
FB_color_space_SPEC_VERSION = 3
FB_COLOR_SPACE_EXTENSION_NAME = "XR_FB_color_space"
FB_hand_tracking_mesh = 1
FB_hand_tracking_mesh_SPEC_VERSION = 3
FB_HAND_TRACKING_MESH_EXTENSION_NAME = "XR_FB_hand_tracking_mesh"
FB_hand_tracking_aim = 1
FB_hand_tracking_aim_SPEC_VERSION = 2
FB_HAND_TRACKING_AIM_EXTENSION_NAME = "XR_FB_hand_tracking_aim"
FB_hand_tracking_capsules = 1
HAND_TRACKING_CAPSULE_POINT_COUNT_FB = 2
HAND_TRACKING_CAPSULE_COUNT_FB = 19
FB_hand_tracking_capsules_SPEC_VERSION = 3
FB_HAND_TRACKING_CAPSULES_EXTENSION_NAME = "XR_FB_hand_tracking_capsules"
FB_HAND_TRACKING_CAPSULE_POINT_COUNT = HAND_TRACKING_CAPSULE_POINT_COUNT_FB
FB_HAND_TRACKING_CAPSULE_COUNT = HAND_TRACKING_CAPSULE_COUNT_FB
FB_spatial_entity = 1
FB_spatial_entity_SPEC_VERSION = 3
FB_SPATIAL_ENTITY_EXTENSION_NAME = "XR_FB_spatial_entity"
FB_foveation = 1
FB_foveation_SPEC_VERSION = 1
FB_FOVEATION_EXTENSION_NAME = "XR_FB_foveation"
FB_foveation_configuration = 1
FB_foveation_configuration_SPEC_VERSION = 1
FB_FOVEATION_CONFIGURATION_EXTENSION_NAME = "XR_FB_foveation_configuration"
FB_keyboard_tracking = 1
MAX_KEYBOARD_TRACKING_NAME_SIZE_FB = 128
FB_keyboard_tracking_SPEC_VERSION = 1
FB_KEYBOARD_TRACKING_EXTENSION_NAME = "XR_FB_keyboard_tracking"
FB_triangle_mesh = 1
FB_triangle_mesh_SPEC_VERSION = 2
FB_TRIANGLE_MESH_EXTENSION_NAME = "XR_FB_triangle_mesh"
FB_passthrough = 1
PASSTHROUGH_COLOR_MAP_MONO_SIZE_FB = 256
FB_passthrough_SPEC_VERSION = 4
FB_PASSTHROUGH_EXTENSION_NAME = "XR_FB_passthrough"
FB_render_model = 1
NULL_RENDER_MODEL_KEY_FB = 0
MAX_RENDER_MODEL_NAME_SIZE_FB = 64
FB_render_model_SPEC_VERSION = 4
FB_RENDER_MODEL_EXTENSION_NAME = "XR_FB_render_model"
VARJO_foveated_rendering = 1
VARJO_foveated_rendering_SPEC_VERSION = 3
VARJO_FOVEATED_RENDERING_EXTENSION_NAME = "XR_VARJO_foveated_rendering"
VARJO_composition_layer_depth_test = 1
VARJO_composition_layer_depth_test_SPEC_VERSION = 2
VARJO_COMPOSITION_LAYER_DEPTH_TEST_EXTENSION_NAME = "XR_VARJO_composition_layer_depth_test"
VARJO_environment_depth_estimation = 1
VARJO_environment_depth_estimation_SPEC_VERSION = 1
VARJO_ENVIRONMENT_DEPTH_ESTIMATION_EXTENSION_NAME = "XR_VARJO_environment_depth_estimation"
VARJO_marker_tracking = 1
VARJO_marker_tracking_SPEC_VERSION = 1
VARJO_MARKER_TRACKING_EXTENSION_NAME = "XR_VARJO_marker_tracking"
VARJO_view_offset = 1
VARJO_view_offset_SPEC_VERSION = 1
VARJO_VIEW_OFFSET_EXTENSION_NAME = "XR_VARJO_view_offset"
VARJO_xr4_controller_interaction = 1
VARJO_xr4_controller_interaction_SPEC_VERSION = 2
VARJO_XR4_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_VARJO_xr4_controller_interaction"
ML_ml2_controller_interaction = 1
ML_ml2_controller_interaction_SPEC_VERSION = 1
ML_ML2_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_ML_ml2_controller_interaction"
ML_frame_end_info = 1
ML_frame_end_info_SPEC_VERSION = 1
ML_FRAME_END_INFO_EXTENSION_NAME = "XR_ML_frame_end_info"
ML_global_dimmer = 1
ML_global_dimmer_SPEC_VERSION = 1
ML_GLOBAL_DIMMER_EXTENSION_NAME = "XR_ML_global_dimmer"
ML_marker_understanding = 1
ML_marker_understanding_SPEC_VERSION = 1
ML_MARKER_UNDERSTANDING_EXTENSION_NAME = "XR_ML_marker_understanding"
ML_localization_map = 1
MAX_LOCALIZATION_MAP_NAME_LENGTH_ML = 64
ML_localization_map_SPEC_VERSION = 1
ML_LOCALIZATION_MAP_EXTENSION_NAME = "XR_ML_localization_map"
ML_spatial_anchors = 1
ML_spatial_anchors_SPEC_VERSION = 1
ML_SPATIAL_ANCHORS_EXTENSION_NAME = "XR_ML_spatial_anchors"
ML_spatial_anchors_storage = 1
ML_spatial_anchors_storage_SPEC_VERSION = 1
ML_SPATIAL_ANCHORS_STORAGE_EXTENSION_NAME = "XR_ML_spatial_anchors_storage"
MSFT_spatial_anchor_persistence = 1
MAX_SPATIAL_ANCHOR_NAME_SIZE_MSFT = 256
MSFT_spatial_anchor_persistence_SPEC_VERSION = 2
MSFT_SPATIAL_ANCHOR_PERSISTENCE_EXTENSION_NAME = "XR_MSFT_spatial_anchor_persistence"
MSFT_scene_marker = 1
MSFT_scene_marker_SPEC_VERSION = 1
MSFT_SCENE_MARKER_EXTENSION_NAME = "XR_MSFT_scene_marker"
ULTRALEAP_hand_tracking_forearm = 1
HAND_FOREARM_JOINT_COUNT_ULTRALEAP = 27
ULTRALEAP_hand_tracking_forearm_SPEC_VERSION = 1
ULTRALEAP_HAND_TRACKING_FOREARM_EXTENSION_NAME = "XR_ULTRALEAP_hand_tracking_forearm"
FB_spatial_entity_query = 1
FB_spatial_entity_query_SPEC_VERSION = 1
FB_SPATIAL_ENTITY_QUERY_EXTENSION_NAME = "XR_FB_spatial_entity_query"
FB_spatial_entity_storage = 1
FB_spatial_entity_storage_SPEC_VERSION = 1
FB_SPATIAL_ENTITY_STORAGE_EXTENSION_NAME = "XR_FB_spatial_entity_storage"
FB_touch_controller_pro = 1
FB_touch_controller_pro_SPEC_VERSION = 1
FB_TOUCH_CONTROLLER_PRO_EXTENSION_NAME = "XR_FB_touch_controller_pro"
FB_spatial_entity_sharing = 1
FB_spatial_entity_sharing_SPEC_VERSION = 1
FB_SPATIAL_ENTITY_SHARING_EXTENSION_NAME = "XR_FB_spatial_entity_sharing"
FB_space_warp = 1
FB_space_warp_SPEC_VERSION = 2
FB_SPACE_WARP_EXTENSION_NAME = "XR_FB_space_warp"
FB_haptic_amplitude_envelope = 1
MAX_HAPTIC_AMPLITUDE_ENVELOPE_SAMPLES_FB = 4000
FB_haptic_amplitude_envelope_SPEC_VERSION = 1
FB_HAPTIC_AMPLITUDE_ENVELOPE_EXTENSION_NAME = "XR_FB_haptic_amplitude_envelope"
FB_scene = 1
FB_scene_SPEC_VERSION = 4
FB_SCENE_EXTENSION_NAME = "XR_FB_scene"
EXT_palm_pose = 1
EXT_palm_pose_SPEC_VERSION = 3
EXT_PALM_POSE_EXTENSION_NAME = "XR_EXT_palm_pose"
ALMALENCE_digital_lens_control = 1
ALMALENCE_digital_lens_control_SPEC_VERSION = 1
ALMALENCE_DIGITAL_LENS_CONTROL_EXTENSION_NAME = "XR_ALMALENCE_digital_lens_control"
FB_scene_capture = 1
FB_scene_capture_SPEC_VERSION = 1
FB_SCENE_CAPTURE_EXTENSION_NAME = "XR_FB_scene_capture"
FB_spatial_entity_container = 1
FB_spatial_entity_container_SPEC_VERSION = 2
FB_SPATIAL_ENTITY_CONTAINER_EXTENSION_NAME = "XR_FB_spatial_entity_container"
META_foveation_eye_tracked = 1
FOVEATION_CENTER_SIZE_META = 2
META_foveation_eye_tracked_SPEC_VERSION = 1
META_FOVEATION_EYE_TRACKED_EXTENSION_NAME = "XR_META_foveation_eye_tracked"
FB_face_tracking = 1
FB_face_tracking_SPEC_VERSION = 1
FB_FACE_TRACKING_EXTENSION_NAME = "XR_FB_face_tracking"
FB_eye_tracking_social = 1
FB_eye_tracking_social_SPEC_VERSION = 1
FB_EYE_TRACKING_SOCIAL_EXTENSION_NAME = "XR_FB_eye_tracking_social"
FB_passthrough_keyboard_hands = 1
FB_passthrough_keyboard_hands_SPEC_VERSION = 2
FB_PASSTHROUGH_KEYBOARD_HANDS_EXTENSION_NAME = "XR_FB_passthrough_keyboard_hands"
FB_composition_layer_settings = 1
FB_composition_layer_settings_SPEC_VERSION = 1
FB_COMPOSITION_LAYER_SETTINGS_EXTENSION_NAME = "XR_FB_composition_layer_settings"
FB_touch_controller_proximity = 1
FB_touch_controller_proximity_SPEC_VERSION = 1
FB_TOUCH_CONTROLLER_PROXIMITY_EXTENSION_NAME = "XR_FB_touch_controller_proximity"
FB_haptic_pcm = 1
MAX_HAPTIC_PCM_BUFFER_SIZE_FB = 4000
FB_haptic_pcm_SPEC_VERSION = 1
FB_HAPTIC_PCM_EXTENSION_NAME = "XR_FB_haptic_pcm"
EXT_frame_synthesis = 1
EXT_frame_synthesis_SPEC_VERSION = 1
EXT_FRAME_SYNTHESIS_EXTENSION_NAME = "XR_EXT_frame_synthesis"
FB_composition_layer_depth_test = 1
FB_composition_layer_depth_test_SPEC_VERSION = 1
FB_COMPOSITION_LAYER_DEPTH_TEST_EXTENSION_NAME = "XR_FB_composition_layer_depth_test"
META_local_dimming = 1
META_local_dimming_SPEC_VERSION = 1
META_LOCAL_DIMMING_EXTENSION_NAME = "XR_META_local_dimming"
META_passthrough_preferences = 1
META_passthrough_preferences_SPEC_VERSION = 1
META_PASSTHROUGH_PREFERENCES_EXTENSION_NAME = "XR_META_passthrough_preferences"
META_virtual_keyboard = 1
MAX_VIRTUAL_KEYBOARD_COMMIT_TEXT_SIZE_META = 3992
META_virtual_keyboard_SPEC_VERSION = 1
META_VIRTUAL_KEYBOARD_EXTENSION_NAME = "XR_META_virtual_keyboard"
OCULUS_external_camera = 1
MAX_EXTERNAL_CAMERA_NAME_SIZE_OCULUS = 32
OCULUS_external_camera_SPEC_VERSION = 1
OCULUS_EXTERNAL_CAMERA_EXTENSION_NAME = "XR_OCULUS_external_camera"
META_performance_metrics = 1
META_performance_metrics_SPEC_VERSION = 2
META_PERFORMANCE_METRICS_EXTENSION_NAME = "XR_META_performance_metrics"
FB_spatial_entity_storage_batch = 1
FB_spatial_entity_storage_batch_SPEC_VERSION = 1
FB_SPATIAL_ENTITY_STORAGE_BATCH_EXTENSION_NAME = "XR_FB_spatial_entity_storage_batch"
META_detached_controllers = 1
META_detached_controllers_SPEC_VERSION = 1
META_DETACHED_CONTROLLERS_EXTENSION_NAME = "XR_META_detached_controllers"
FB_spatial_entity_user = 1
FB_spatial_entity_user_SPEC_VERSION = 1
FB_SPATIAL_ENTITY_USER_EXTENSION_NAME = "XR_FB_spatial_entity_user"
META_headset_id = 1
META_headset_id_SPEC_VERSION = 2
META_HEADSET_ID_EXTENSION_NAME = "XR_META_headset_id"
META_hand_tracking_microgestures = 1
META_hand_tracking_microgestures_SPEC_VERSION = 1
META_HAND_TRACKING_MICROGESTURES_EXTENSION_NAME = "XR_META_hand_tracking_microgestures"
META_recommended_layer_resolution = 1
META_recommended_layer_resolution_SPEC_VERSION = 1
META_RECOMMENDED_LAYER_RESOLUTION_EXTENSION_NAME = "XR_META_recommended_layer_resolution"
META_passthrough_color_lut = 1
META_passthrough_color_lut_SPEC_VERSION = 1
META_PASSTHROUGH_COLOR_LUT_EXTENSION_NAME = "XR_META_passthrough_color_lut"
META_spatial_entity_mesh = 1
META_spatial_entity_mesh_SPEC_VERSION = 1
META_SPATIAL_ENTITY_MESH_EXTENSION_NAME = "XR_META_spatial_entity_mesh"
META_automatic_layer_filter = 1
META_automatic_layer_filter_SPEC_VERSION = 1
META_AUTOMATIC_LAYER_FILTER_EXTENSION_NAME = "XR_META_automatic_layer_filter"
META_body_tracking_full_body = 1
META_body_tracking_full_body_SPEC_VERSION = 1
META_BODY_TRACKING_FULL_BODY_EXTENSION_NAME = "XR_META_body_tracking_full_body"
META_touch_controller_plus = 1
META_touch_controller_plus_SPEC_VERSION = 1
META_TOUCH_CONTROLLER_PLUS_EXTENSION_NAME = "XR_META_touch_controller_plus"
META_passthrough_layer_resumed_event = 1
META_passthrough_layer_resumed_event_SPEC_VERSION = 1
META_PASSTHROUGH_LAYER_RESUMED_EVENT_EXTENSION_NAME = "XR_META_passthrough_layer_resumed_event"
FB_face_tracking2 = 1
FB_face_tracking2_SPEC_VERSION = 1
FB_FACE_TRACKING2_EXTENSION_NAME = "XR_FB_face_tracking2"
META_spatial_entity_sharing = 1
META_spatial_entity_sharing_SPEC_VERSION = 1
META_SPATIAL_ENTITY_SHARING_EXTENSION_NAME = "XR_META_spatial_entity_sharing"
MAX_SPACES_PER_SHARE_REQUEST_META = 32
META_environment_depth = 1
META_environment_depth_SPEC_VERSION = 1
META_ENVIRONMENT_DEPTH_EXTENSION_NAME = "XR_META_environment_depth"
EXT_uuid = 1
EXT_uuid_SPEC_VERSION = 1
EXT_UUID_EXTENSION_NAME = "XR_EXT_uuid"
UUID_SIZE_EXT = 16
EXT_render_model = 1
MAX_RENDER_MODEL_ASSET_NODE_NAME_SIZE_EXT = 64
EXT_render_model_SPEC_VERSION = 1
EXT_RENDER_MODEL_EXTENSION_NAME = "XR_EXT_render_model"
NULL_RENDER_MODEL_ID_EXT = 0
EXT_interaction_render_model = 1
EXT_interaction_render_model_SPEC_VERSION = 1
EXT_INTERACTION_RENDER_MODEL_EXTENSION_NAME = "XR_EXT_interaction_render_model"
EXT_hand_interaction = 1
EXT_hand_interaction_SPEC_VERSION = 1
EXT_HAND_INTERACTION_EXTENSION_NAME = "XR_EXT_hand_interaction"
QCOM_tracking_optimization_settings = 1
QCOM_tracking_optimization_settings_SPEC_VERSION = 1
QCOM_TRACKING_OPTIMIZATION_SETTINGS_EXTENSION_NAME = "XR_QCOM_tracking_optimization_settings"
HTC_passthrough = 1
HTC_passthrough_SPEC_VERSION = 1
HTC_PASSTHROUGH_EXTENSION_NAME = "XR_HTC_passthrough"
HTC_foveation = 1
HTC_foveation_SPEC_VERSION = 1
HTC_FOVEATION_EXTENSION_NAME = "XR_HTC_foveation"
HTC_anchor = 1
MAX_SPATIAL_ANCHOR_NAME_SIZE_HTC = 256
HTC_anchor_SPEC_VERSION = 1
HTC_ANCHOR_EXTENSION_NAME = "XR_HTC_anchor"
HTC_body_tracking = 1
BODY_JOINT_COUNT_HTC = 26
HTC_body_tracking_SPEC_VERSION = 1
HTC_BODY_TRACKING_EXTENSION_NAME = "XR_HTC_body_tracking"
EXT_active_action_set_priority = 1
EXT_active_action_set_priority_SPEC_VERSION = 1
EXT_ACTIVE_ACTION_SET_PRIORITY_EXTENSION_NAME = "XR_EXT_active_action_set_priority"
MNDX_force_feedback_curl = 1
MNDX_force_feedback_curl_SPEC_VERSION = 1
MNDX_FORCE_FEEDBACK_CURL_EXTENSION_NAME = "XR_MNDX_force_feedback_curl"
BD_controller_interaction = 1
BD_controller_interaction_SPEC_VERSION = 2
BD_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_BD_controller_interaction"
BD_body_tracking = 1
BODY_JOINT_COUNT_BD = 24
BODY_JOINT_WITHOUT_ARM_COUNT_BD = 16
BD_body_tracking_SPEC_VERSION = 1
BD_BODY_TRACKING_EXTENSION_NAME = "XR_BD_body_tracking"
BD_spatial_sensing = 1
BD_spatial_sensing_SPEC_VERSION = 1
BD_SPATIAL_SENSING_EXTENSION_NAME = "XR_BD_spatial_sensing"
BD_spatial_anchor = 1
BD_spatial_anchor_SPEC_VERSION = 1
BD_SPATIAL_ANCHOR_EXTENSION_NAME = "XR_BD_spatial_anchor"
BD_spatial_anchor_sharing = 1
BD_spatial_anchor_sharing_SPEC_VERSION = 2
BD_SPATIAL_ANCHOR_SHARING_EXTENSION_NAME = "XR_BD_spatial_anchor_sharing"
BD_spatial_scene = 1
BD_spatial_scene_SPEC_VERSION = 1
BD_SPATIAL_SCENE_EXTENSION_NAME = "XR_BD_spatial_scene"
BD_spatial_mesh = 1
BD_spatial_mesh_SPEC_VERSION = 1
BD_SPATIAL_MESH_EXTENSION_NAME = "XR_BD_spatial_mesh"
BD_future_progress = 1
BD_future_progress_SPEC_VERSION = 1
BD_FUTURE_PROGRESS_EXTENSION_NAME = "XR_BD_future_progress"
BD_spatial_plane = 1
BD_spatial_plane_SPEC_VERSION = 1
BD_SPATIAL_PLANE_EXTENSION_NAME = "XR_BD_spatial_plane"
EXT_local_floor = 1
EXT_local_floor_SPEC_VERSION = 1
EXT_LOCAL_FLOOR_EXTENSION_NAME = "XR_EXT_local_floor"
EXT_hand_tracking_data_source = 1
EXT_hand_tracking_data_source_SPEC_VERSION = 1
EXT_HAND_TRACKING_DATA_SOURCE_EXTENSION_NAME = "XR_EXT_hand_tracking_data_source"
EXT_plane_detection = 1
EXT_plane_detection_SPEC_VERSION = 2
EXT_PLANE_DETECTION_EXTENSION_NAME = "XR_EXT_plane_detection"
OPPO_controller_interaction = 1
OPPO_controller_interaction_SPEC_VERSION = 1
OPPO_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_OPPO_controller_interaction"
EXT_future = 1
EXT_future_SPEC_VERSION = 1
EXT_FUTURE_EXTENSION_NAME = "XR_EXT_future"
NULL_FUTURE_EXT = 0
EXT_user_presence = 1
EXT_user_presence_SPEC_VERSION = 1
EXT_USER_PRESENCE_EXTENSION_NAME = "XR_EXT_user_presence"
ML_user_calibration = 1
ML_user_calibration_SPEC_VERSION = 1
ML_USER_CALIBRATION_EXTENSION_NAME = "XR_ML_user_calibration"
ML_system_notifications = 1
ML_system_notifications_SPEC_VERSION = 1
ML_SYSTEM_NOTIFICATIONS_EXTENSION_NAME = "XR_ML_system_notifications"
ML_world_mesh_detection = 1
ML_world_mesh_detection_SPEC_VERSION = 1
ML_WORLD_MESH_DETECTION_EXTENSION_NAME = "XR_ML_world_mesh_detection"
ML_facial_expression = 1
ML_facial_expression_SPEC_VERSION = 1
ML_FACIAL_EXPRESSION_EXTENSION_NAME = "XR_ML_facial_expression"
ML_view_configuration_depth_range_change = 1
ML_view_configuration_depth_range_change_SPEC_VERSION = 1
ML_VIEW_CONFIGURATION_DEPTH_RANGE_CHANGE_EXTENSION_NAME = "XR_ML_view_configuration_depth_range_change"
YVR_controller_interaction = 1
YVR_controller_interaction_SPEC_VERSION = 1
YVR_CONTROLLER_INTERACTION_EXTENSION_NAME = "XR_YVR_controller_interaction"
META_simultaneous_hands_and_controllers = 1
META_simultaneous_hands_and_controllers_SPEC_VERSION = 1
META_SIMULTANEOUS_HANDS_AND_CONTROLLERS_EXTENSION_NAME = "XR_META_simultaneous_hands_and_controllers"
EXT_composition_layer_inverted_alpha = 1
EXT_composition_layer_inverted_alpha_SPEC_VERSION = 1
EXT_COMPOSITION_LAYER_INVERTED_ALPHA_EXTENSION_NAME = "XR_EXT_composition_layer_inverted_alpha"
META_colocation_discovery = 1
MAX_COLOCATION_DISCOVERY_BUFFER_SIZE_META = 1024
META_colocation_discovery_SPEC_VERSION = 1
META_COLOCATION_DISCOVERY_EXTENSION_NAME = "XR_META_colocation_discovery"
META_spatial_entity_group_sharing = 1
META_spatial_entity_group_sharing_SPEC_VERSION = 1
META_SPATIAL_ENTITY_GROUP_SHARING_EXTENSION_NAME = "XR_META_spatial_entity_group_sharing"
EXT_spatial_entity = 1
NULL_SPATIAL_ENTITY_ID_EXT = 0
NULL_SPATIAL_BUFFER_ID_EXT = 0
EXT_spatial_entity_SPEC_VERSION = 1
EXT_SPATIAL_ENTITY_EXTENSION_NAME = "XR_EXT_spatial_entity"
EXT_spatial_plane_tracking = 1
EXT_spatial_plane_tracking_SPEC_VERSION = 1
EXT_SPATIAL_PLANE_TRACKING_EXTENSION_NAME = "XR_EXT_spatial_plane_tracking"
EXT_spatial_marker_tracking = 1
EXT_spatial_marker_tracking_SPEC_VERSION = 1
EXT_SPATIAL_MARKER_TRACKING_EXTENSION_NAME = "XR_EXT_spatial_marker_tracking"
LOGITECH_mx_ink_stylus_interaction = 1
LOGITECH_mx_ink_stylus_interaction_SPEC_VERSION = 1
LOGITECH_MX_INK_STYLUS_INTERACTION_EXTENSION_NAME = "XR_LOGITECH_mx_ink_stylus_interaction"
EXT_spatial_anchor = 1
EXT_spatial_anchor_SPEC_VERSION = 1
EXT_SPATIAL_ANCHOR_EXTENSION_NAME = "XR_EXT_spatial_anchor"
EXT_spatial_persistence = 1
EXT_spatial_persistence_SPEC_VERSION = 1
EXT_SPATIAL_PERSISTENCE_EXTENSION_NAME = "XR_EXT_spatial_persistence"
EXT_spatial_persistence_operations = 1
EXT_spatial_persistence_operations_SPEC_VERSION = 1
EXT_SPATIAL_PERSISTENCE_OPERATIONS_EXTENSION_NAME = "XR_EXT_spatial_persistence_operations"
SPACE_VELOCITY_LINEAR_VALID_BIT = 0x00000001
SPACE_VELOCITY_ANGULAR_VALID_BIT = 0x00000002
SPACE_LOCATION_ORIENTATION_VALID_BIT = 0x00000001
SPACE_LOCATION_POSITION_VALID_BIT = 0x00000002
SPACE_LOCATION_ORIENTATION_TRACKED_BIT = 0x00000004
SPACE_LOCATION_POSITION_TRACKED_BIT = 0x00000008
SWAPCHAIN_CREATE_PROTECTED_CONTENT_BIT = 0x00000001
SWAPCHAIN_CREATE_STATIC_IMAGE_BIT = 0x00000002
SWAPCHAIN_USAGE_COLOR_ATTACHMENT_BIT = 0x00000001
SWAPCHAIN_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT = 0x00000002
SWAPCHAIN_USAGE_UNORDERED_ACCESS_BIT = 0x00000004
SWAPCHAIN_USAGE_TRANSFER_SRC_BIT = 0x00000008
SWAPCHAIN_USAGE_TRANSFER_DST_BIT = 0x00000010
SWAPCHAIN_USAGE_SAMPLED_BIT = 0x00000020
SWAPCHAIN_USAGE_MUTABLE_FORMAT_BIT = 0x00000040
SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_MND = 0x00000080
SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_KHR = 0x00000080
COMPOSITION_LAYER_CORRECT_CHROMATIC_ABERRATION_BIT = 0x00000001
COMPOSITION_LAYER_BLEND_TEXTURE_SOURCE_ALPHA_BIT = 0x00000002
COMPOSITION_LAYER_UNPREMULTIPLIED_ALPHA_BIT = 0x00000004
COMPOSITION_LAYER_INVERTED_ALPHA_BIT_EXT = 0x00000008
VIEW_STATE_ORIENTATION_VALID_BIT = 0x00000001
VIEW_STATE_POSITION_VALID_BIT = 0x00000002
VIEW_STATE_ORIENTATION_TRACKED_BIT = 0x00000004
VIEW_STATE_POSITION_TRACKED_BIT = 0x00000008
INPUT_SOURCE_LOCALIZED_NAME_USER_PATH_BIT = 0x00000001
INPUT_SOURCE_LOCALIZED_NAME_INTERACTION_PROFILE_BIT = 0x00000002
INPUT_SOURCE_LOCALIZED_NAME_COMPONENT_BIT = 0x00000004
DEBUG_UTILS_MESSAGE_SEVERITY_VERBOSE_BIT_EXT = 0x00000001
DEBUG_UTILS_MESSAGE_SEVERITY_INFO_BIT_EXT = 0x00000010
DEBUG_UTILS_MESSAGE_SEVERITY_WARNING_BIT_EXT = 0x00000100
DEBUG_UTILS_MESSAGE_SEVERITY_ERROR_BIT_EXT = 0x00001000
DEBUG_UTILS_MESSAGE_TYPE_GENERAL_BIT_EXT = 0x00000001
DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT = 0x00000002
DEBUG_UTILS_MESSAGE_TYPE_PERFORMANCE_BIT_EXT = 0x00000004
DEBUG_UTILS_MESSAGE_TYPE_CONFORMANCE_BIT_EXT = 0x00000008
OVERLAY_MAIN_SESSION_ENABLED_COMPOSITION_LAYER_INFO_DEPTH_BIT_EXTX = 0x00000001
COMPOSITION_LAYER_IMAGE_LAYOUT_VERTICAL_FLIP_BIT_FB = 0x00000001
COMPOSITION_LAYER_SECURE_CONTENT_EXCLUDE_LAYER_BIT_FB = 0x00000001
COMPOSITION_LAYER_SECURE_CONTENT_REPLACE_LAYER_BIT_FB = 0x00000002
HAND_TRACKING_AIM_COMPUTED_BIT_FB = 0x00000001
HAND_TRACKING_AIM_VALID_BIT_FB = 0x00000002
HAND_TRACKING_AIM_INDEX_PINCHING_BIT_FB = 0x00000004
HAND_TRACKING_AIM_MIDDLE_PINCHING_BIT_FB = 0x00000008
HAND_TRACKING_AIM_RING_PINCHING_BIT_FB = 0x00000010
HAND_TRACKING_AIM_LITTLE_PINCHING_BIT_FB = 0x00000020
HAND_TRACKING_AIM_SYSTEM_GESTURE_BIT_FB = 0x00000040
HAND_TRACKING_AIM_DOMINANT_HAND_BIT_FB = 0x00000080
HAND_TRACKING_AIM_MENU_PRESSED_BIT_FB = 0x00000100
SWAPCHAIN_CREATE_FOVEATION_SCALED_BIN_BIT_FB = 0x00000001
SWAPCHAIN_CREATE_FOVEATION_FRAGMENT_DENSITY_MAP_BIT_FB = 0x00000002
KEYBOARD_TRACKING_EXISTS_BIT_FB = 0x00000001
KEYBOARD_TRACKING_LOCAL_BIT_FB = 0x00000002
KEYBOARD_TRACKING_REMOTE_BIT_FB = 0x00000004
KEYBOARD_TRACKING_CONNECTED_BIT_FB = 0x00000008
KEYBOARD_TRACKING_QUERY_LOCAL_BIT_FB = 0x00000002
KEYBOARD_TRACKING_QUERY_REMOTE_BIT_FB = 0x00000004
TRIANGLE_MESH_MUTABLE_BIT_FB = 0x00000001
PASSTHROUGH_CAPABILITY_BIT_FB = 0x00000001
PASSTHROUGH_CAPABILITY_COLOR_BIT_FB = 0x00000002
PASSTHROUGH_CAPABILITY_LAYER_DEPTH_BIT_FB = 0x00000004
PASSTHROUGH_IS_RUNNING_AT_CREATION_BIT_FB = 0x00000001
PASSTHROUGH_LAYER_DEPTH_BIT_FB = 0x00000002
PASSTHROUGH_STATE_CHANGED_REINIT_REQUIRED_BIT_FB = 0x00000001
PASSTHROUGH_STATE_CHANGED_NON_RECOVERABLE_ERROR_BIT_FB = 0x00000002
PASSTHROUGH_STATE_CHANGED_RECOVERABLE_ERROR_BIT_FB = 0x00000004
PASSTHROUGH_STATE_CHANGED_RESTORED_ERROR_BIT_FB = 0x00000008
RENDER_MODEL_SUPPORTS_GLTF_2_0_SUBSET_1_BIT_FB = 0x00000001
RENDER_MODEL_SUPPORTS_GLTF_2_0_SUBSET_2_BIT_FB = 0x00000002
FRAME_END_INFO_PROTECTED_BIT_ML = 0x00000001
FRAME_END_INFO_VIGNETTE_BIT_ML = 0x00000002
GLOBAL_DIMMER_FRAME_END_INFO_ENABLED_BIT_ML = 0x00000001
LOCALIZATION_MAP_ERROR_UNKNOWN_BIT_ML = 0x00000001
LOCALIZATION_MAP_ERROR_OUT_OF_MAPPED_AREA_BIT_ML = 0x00000002
LOCALIZATION_MAP_ERROR_LOW_FEATURE_COUNT_BIT_ML = 0x00000004
LOCALIZATION_MAP_ERROR_EXCESSIVE_MOTION_BIT_ML = 0x00000008
LOCALIZATION_MAP_ERROR_LOW_LIGHT_BIT_ML = 0x00000010
LOCALIZATION_MAP_ERROR_HEADPOSE_BIT_ML = 0x00000020
COMPOSITION_LAYER_SPACE_WARP_INFO_FRAME_SKIP_BIT_FB = 0x00000001
SEMANTIC_LABELS_SUPPORT_MULTIPLE_SEMANTIC_LABELS_BIT_FB = 0x00000001
SEMANTIC_LABELS_SUPPORT_ACCEPT_DESK_TO_TABLE_MIGRATION_BIT_FB = 0x00000002
SEMANTIC_LABELS_SUPPORT_ACCEPT_INVISIBLE_WALL_FACE_BIT_FB = 0x00000004
DIGITAL_LENS_CONTROL_PROCESSING_DISABLE_BIT_ALMALENCE = 0x00000001
FOVEATION_EYE_TRACKED_STATE_VALID_BIT_META = 0x00000001
COMPOSITION_LAYER_SETTINGS_NORMAL_SUPER_SAMPLING_BIT_FB = 0x00000001
COMPOSITION_LAYER_SETTINGS_QUALITY_SUPER_SAMPLING_BIT_FB = 0x00000002
COMPOSITION_LAYER_SETTINGS_NORMAL_SHARPENING_BIT_FB = 0x00000004
COMPOSITION_LAYER_SETTINGS_QUALITY_SHARPENING_BIT_FB = 0x00000008
COMPOSITION_LAYER_SETTINGS_AUTO_LAYER_FILTER_BIT_META = 0x00000020
FRAME_SYNTHESIS_INFO_USE_2D_MOTION_VECTOR_BIT_EXT = 0x00000001
FRAME_SYNTHESIS_INFO_REQUEST_RELAXED_FRAME_INTERVAL_BIT_EXT = 0x00000002
PASSTHROUGH_PREFERENCE_DEFAULT_TO_ACTIVE_BIT_META = 0x00000001
VIRTUAL_KEYBOARD_INPUT_STATE_PRESSED_BIT_META = 0x00000001
EXTERNAL_CAMERA_STATUS_CONNECTED_BIT_OCULUS = 0x00000001
EXTERNAL_CAMERA_STATUS_CALIBRATING_BIT_OCULUS = 0x00000002
EXTERNAL_CAMERA_STATUS_CALIBRATION_FAILED_BIT_OCULUS = 0x00000004
EXTERNAL_CAMERA_STATUS_CALIBRATED_BIT_OCULUS = 0x00000008
EXTERNAL_CAMERA_STATUS_CAPTURING_BIT_OCULUS = 0x00000010
PERFORMANCE_METRICS_COUNTER_ANY_VALUE_VALID_BIT_META = 0x00000001
PERFORMANCE_METRICS_COUNTER_UINT_VALUE_VALID_BIT_META = 0x00000002
PERFORMANCE_METRICS_COUNTER_FLOAT_VALUE_VALID_BIT_META = 0x00000004
FOVEATION_DYNAMIC_LEVEL_ENABLED_BIT_HTC = 0x00000001
FOVEATION_DYNAMIC_CLEAR_FOV_ENABLED_BIT_HTC = 0x00000002
FOVEATION_DYNAMIC_FOCAL_CENTER_OFFSET_ENABLED_BIT_HTC = 0x00000004
SPATIAL_MESH_CONFIG_SEMANTIC_BIT_BD = 0x00000001
SPATIAL_MESH_CONFIG_ALIGN_SEMANTIC_WITH_VERTEX_BIT_BD = 0x00000002
PLANE_DETECTION_CAPABILITY_PLANE_DETECTION_BIT_EXT = 0x00000001
PLANE_DETECTION_CAPABILITY_PLANE_HOLES_BIT_EXT = 0x00000002
PLANE_DETECTION_CAPABILITY_SEMANTIC_CEILING_BIT_EXT = 0x00000004
PLANE_DETECTION_CAPABILITY_SEMANTIC_FLOOR_BIT_EXT = 0x00000008
PLANE_DETECTION_CAPABILITY_SEMANTIC_WALL_BIT_EXT = 0x00000010
PLANE_DETECTION_CAPABILITY_SEMANTIC_PLATFORM_BIT_EXT = 0x00000020
PLANE_DETECTION_CAPABILITY_ORIENTATION_BIT_EXT = 0x00000040
PLANE_DETECTOR_ENABLE_CONTOUR_BIT_EXT = 0x00000001
WORLD_MESH_DETECTOR_POINT_CLOUD_BIT_ML = 0x00000001
WORLD_MESH_DETECTOR_COMPUTE_NORMALS_BIT_ML = 0x00000002
WORLD_MESH_DETECTOR_COMPUTE_CONFIDENCE_BIT_ML = 0x00000004
WORLD_MESH_DETECTOR_PLANARIZE_BIT_ML = 0x00000008
WORLD_MESH_DETECTOR_REMOVE_MESH_SKIRT_BIT_ML = 0x00000010
WORLD_MESH_DETECTOR_INDEX_ORDER_CW_BIT_ML = 0x00000020
FACIAL_EXPRESSION_BLEND_SHAPE_PROPERTIES_VALID_BIT_ML = 0x00000001
FACIAL_EXPRESSION_BLEND_SHAPE_PROPERTIES_TRACKED_BIT_ML = 0x00000002


__all__ = [
    "ALMALENCE_DIGITAL_LENS_CONTROL_EXTENSION_NAME",
    "ALMALENCE_digital_lens_control",
    "ALMALENCE_digital_lens_control_SPEC_VERSION",
    "BD_BODY_TRACKING_EXTENSION_NAME",
    "BD_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "BD_FUTURE_PROGRESS_EXTENSION_NAME",
    "BD_SPATIAL_ANCHOR_EXTENSION_NAME",
    "BD_SPATIAL_ANCHOR_SHARING_EXTENSION_NAME",
    "BD_SPATIAL_MESH_EXTENSION_NAME",
    "BD_SPATIAL_PLANE_EXTENSION_NAME",
    "BD_SPATIAL_SCENE_EXTENSION_NAME",
    "BD_SPATIAL_SENSING_EXTENSION_NAME",
    "BD_body_tracking",
    "BD_body_tracking_SPEC_VERSION",
    "BD_controller_interaction",
    "BD_controller_interaction_SPEC_VERSION",
    "BD_future_progress",
    "BD_future_progress_SPEC_VERSION",
    "BD_spatial_anchor",
    "BD_spatial_anchor_SPEC_VERSION",
    "BD_spatial_anchor_sharing",
    "BD_spatial_anchor_sharing_SPEC_VERSION",
    "BD_spatial_mesh",
    "BD_spatial_mesh_SPEC_VERSION",
    "BD_spatial_plane",
    "BD_spatial_plane_SPEC_VERSION",
    "BD_spatial_scene",
    "BD_spatial_scene_SPEC_VERSION",
    "BD_spatial_sensing",
    "BD_spatial_sensing_SPEC_VERSION",
    "BODY_JOINT_COUNT_BD",
    "BODY_JOINT_COUNT_HTC",
    "BODY_JOINT_WITHOUT_ARM_COUNT_BD",
    "COMPOSITION_LAYER_BLEND_TEXTURE_SOURCE_ALPHA_BIT",
    "COMPOSITION_LAYER_CORRECT_CHROMATIC_ABERRATION_BIT",
    "COMPOSITION_LAYER_IMAGE_LAYOUT_VERTICAL_FLIP_BIT_FB",
    "COMPOSITION_LAYER_INVERTED_ALPHA_BIT_EXT",
    "COMPOSITION_LAYER_SECURE_CONTENT_EXCLUDE_LAYER_BIT_FB",
    "COMPOSITION_LAYER_SECURE_CONTENT_REPLACE_LAYER_BIT_FB",
    "COMPOSITION_LAYER_SETTINGS_AUTO_LAYER_FILTER_BIT_META",
    "COMPOSITION_LAYER_SETTINGS_NORMAL_SHARPENING_BIT_FB",
    "COMPOSITION_LAYER_SETTINGS_NORMAL_SUPER_SAMPLING_BIT_FB",
    "COMPOSITION_LAYER_SETTINGS_QUALITY_SHARPENING_BIT_FB",
    "COMPOSITION_LAYER_SETTINGS_QUALITY_SUPER_SAMPLING_BIT_FB",
    "COMPOSITION_LAYER_SPACE_WARP_INFO_FRAME_SKIP_BIT_FB",
    "COMPOSITION_LAYER_UNPREMULTIPLIED_ALPHA_BIT",
    "DEBUG_UTILS_MESSAGE_SEVERITY_ERROR_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_SEVERITY_INFO_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_SEVERITY_VERBOSE_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_SEVERITY_WARNING_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_TYPE_CONFORMANCE_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_TYPE_GENERAL_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_TYPE_PERFORMANCE_BIT_EXT",
    "DEBUG_UTILS_MESSAGE_TYPE_VALIDATION_BIT_EXT",
    "DIGITAL_LENS_CONTROL_PROCESSING_DISABLE_BIT_ALMALENCE",
    "EPIC_VIEW_CONFIGURATION_FOV_EXTENSION_NAME",
    "EPIC_view_configuration_fov",
    "EPIC_view_configuration_fov_SPEC_VERSION",
    "EXTENSION_ENUM_BASE",
    "EXTENSION_ENUM_STRIDE",
    "EXTERNAL_CAMERA_STATUS_CALIBRATED_BIT_OCULUS",
    "EXTERNAL_CAMERA_STATUS_CALIBRATING_BIT_OCULUS",
    "EXTERNAL_CAMERA_STATUS_CALIBRATION_FAILED_BIT_OCULUS",
    "EXTERNAL_CAMERA_STATUS_CAPTURING_BIT_OCULUS",
    "EXTERNAL_CAMERA_STATUS_CONNECTED_BIT_OCULUS",
    "EXTX_OVERLAY_EXTENSION_NAME",
    "EXTX_overlay",
    "EXTX_overlay_SPEC_VERSION",
    "EXT_ACTIVE_ACTION_SET_PRIORITY_EXTENSION_NAME",
    "EXT_COMPOSITION_LAYER_INVERTED_ALPHA_EXTENSION_NAME",
    "EXT_CONFORMANCE_AUTOMATION_EXTENSION_NAME",
    "EXT_DEBUG_UTILS_EXTENSION_NAME",
    "EXT_DPAD_BINDING_EXTENSION_NAME",
    "EXT_EYE_GAZE_INTERACTION_EXTENSION_NAME",
    "EXT_FRAME_SYNTHESIS_EXTENSION_NAME",
    "EXT_FUTURE_EXTENSION_NAME",
    "EXT_HAND_INTERACTION_EXTENSION_NAME",
    "EXT_HAND_JOINTS_MOTION_RANGE_EXTENSION_NAME",
    "EXT_HAND_TRACKING_DATA_SOURCE_EXTENSION_NAME",
    "EXT_HAND_TRACKING_EXTENSION_NAME",
    "EXT_HP_MIXED_REALITY_CONTROLLER_EXTENSION_NAME",
    "EXT_INTERACTION_RENDER_MODEL_EXTENSION_NAME",
    "EXT_LOCAL_FLOOR_EXTENSION_NAME",
    "EXT_PALM_POSE_EXTENSION_NAME",
    "EXT_PERFORMANCE_SETTINGS_EXTENSION_NAME",
    "EXT_PLANE_DETECTION_EXTENSION_NAME",
    "EXT_RENDER_MODEL_EXTENSION_NAME",
    "EXT_SAMSUNG_ODYSSEY_CONTROLLER_EXTENSION_NAME",
    "EXT_SPATIAL_ANCHOR_EXTENSION_NAME",
    "EXT_SPATIAL_ENTITY_EXTENSION_NAME",
    "EXT_SPATIAL_MARKER_TRACKING_EXTENSION_NAME",
    "EXT_SPATIAL_PERSISTENCE_EXTENSION_NAME",
    "EXT_SPATIAL_PERSISTENCE_OPERATIONS_EXTENSION_NAME",
    "EXT_SPATIAL_PLANE_TRACKING_EXTENSION_NAME",
    "EXT_THERMAL_QUERY_EXTENSION_NAME",
    "EXT_USER_PRESENCE_EXTENSION_NAME",
    "EXT_UUID_EXTENSION_NAME",
    "EXT_VIEW_CONFIGURATION_DEPTH_RANGE_EXTENSION_NAME",
    "EXT_WIN32_APPCONTAINER_COMPATIBLE_EXTENSION_NAME",
    "EXT_active_action_set_priority",
    "EXT_active_action_set_priority_SPEC_VERSION",
    "EXT_composition_layer_inverted_alpha",
    "EXT_composition_layer_inverted_alpha_SPEC_VERSION",
    "EXT_conformance_automation",
    "EXT_conformance_automation_SPEC_VERSION",
    "EXT_debug_utils",
    "EXT_debug_utils_SPEC_VERSION",
    "EXT_dpad_binding",
    "EXT_dpad_binding_SPEC_VERSION",
    "EXT_eye_gaze_interaction",
    "EXT_eye_gaze_interaction_SPEC_VERSION",
    "EXT_frame_synthesis",
    "EXT_frame_synthesis_SPEC_VERSION",
    "EXT_future",
    "EXT_future_SPEC_VERSION",
    "EXT_hand_interaction",
    "EXT_hand_interaction_SPEC_VERSION",
    "EXT_hand_joints_motion_range",
    "EXT_hand_joints_motion_range_SPEC_VERSION",
    "EXT_hand_tracking",
    "EXT_hand_tracking_SPEC_VERSION",
    "EXT_hand_tracking_data_source",
    "EXT_hand_tracking_data_source_SPEC_VERSION",
    "EXT_hp_mixed_reality_controller",
    "EXT_hp_mixed_reality_controller_SPEC_VERSION",
    "EXT_interaction_render_model",
    "EXT_interaction_render_model_SPEC_VERSION",
    "EXT_local_floor",
    "EXT_local_floor_SPEC_VERSION",
    "EXT_palm_pose",
    "EXT_palm_pose_SPEC_VERSION",
    "EXT_performance_settings",
    "EXT_performance_settings_SPEC_VERSION",
    "EXT_plane_detection",
    "EXT_plane_detection_SPEC_VERSION",
    "EXT_render_model",
    "EXT_render_model_SPEC_VERSION",
    "EXT_samsung_odyssey_controller",
    "EXT_samsung_odyssey_controller_SPEC_VERSION",
    "EXT_spatial_anchor",
    "EXT_spatial_anchor_SPEC_VERSION",
    "EXT_spatial_entity",
    "EXT_spatial_entity_SPEC_VERSION",
    "EXT_spatial_marker_tracking",
    "EXT_spatial_marker_tracking_SPEC_VERSION",
    "EXT_spatial_persistence",
    "EXT_spatial_persistence_SPEC_VERSION",
    "EXT_spatial_persistence_operations",
    "EXT_spatial_persistence_operations_SPEC_VERSION",
    "EXT_spatial_plane_tracking",
    "EXT_spatial_plane_tracking_SPEC_VERSION",
    "EXT_thermal_query",
    "EXT_thermal_query_SPEC_VERSION",
    "EXT_user_presence",
    "EXT_user_presence_SPEC_VERSION",
    "EXT_uuid",
    "EXT_uuid_SPEC_VERSION",
    "EXT_view_configuration_depth_range",
    "EXT_view_configuration_depth_range_SPEC_VERSION",
    "EXT_win32_appcontainer_compatible",
    "EXT_win32_appcontainer_compatible_SPEC_VERSION",
    "FACIAL_EXPRESSION_BLEND_SHAPE_PROPERTIES_TRACKED_BIT_ML",
    "FACIAL_EXPRESSION_BLEND_SHAPE_PROPERTIES_VALID_BIT_ML",
    "FACIAL_EXPRESSION_EYE_COUNT_HTC",
    "FACIAL_EXPRESSION_LIP_COUNT_HTC",
    "FALSE",
    "FB_BODY_TRACKING_EXTENSION_NAME",
    "FB_COLOR_SPACE_EXTENSION_NAME",
    "FB_COMPOSITION_LAYER_ALPHA_BLEND_EXTENSION_NAME",
    "FB_COMPOSITION_LAYER_DEPTH_TEST_EXTENSION_NAME",
    "FB_COMPOSITION_LAYER_IMAGE_LAYOUT_EXTENSION_NAME",
    "FB_COMPOSITION_LAYER_SECURE_CONTENT_EXTENSION_NAME",
    "FB_COMPOSITION_LAYER_SETTINGS_EXTENSION_NAME",
    "FB_DISPLAY_REFRESH_RATE_EXTENSION_NAME",
    "FB_EYE_TRACKING_SOCIAL_EXTENSION_NAME",
    "FB_FACE_TRACKING2_EXTENSION_NAME",
    "FB_FACE_TRACKING_EXTENSION_NAME",
    "FB_FOVEATION_CONFIGURATION_EXTENSION_NAME",
    "FB_FOVEATION_EXTENSION_NAME",
    "FB_HAND_TRACKING_AIM_EXTENSION_NAME",
    "FB_HAND_TRACKING_CAPSULES_EXTENSION_NAME",
    "FB_HAND_TRACKING_CAPSULE_COUNT",
    "FB_HAND_TRACKING_CAPSULE_POINT_COUNT",
    "FB_HAND_TRACKING_MESH_EXTENSION_NAME",
    "FB_HAPTIC_AMPLITUDE_ENVELOPE_EXTENSION_NAME",
    "FB_HAPTIC_PCM_EXTENSION_NAME",
    "FB_KEYBOARD_TRACKING_EXTENSION_NAME",
    "FB_PASSTHROUGH_EXTENSION_NAME",
    "FB_PASSTHROUGH_KEYBOARD_HANDS_EXTENSION_NAME",
    "FB_RENDER_MODEL_EXTENSION_NAME",
    "FB_SCENE_CAPTURE_EXTENSION_NAME",
    "FB_SCENE_EXTENSION_NAME",
    "FB_SPACE_WARP_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_CONTAINER_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_QUERY_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_SHARING_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_STORAGE_BATCH_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_STORAGE_EXTENSION_NAME",
    "FB_SPATIAL_ENTITY_USER_EXTENSION_NAME",
    "FB_SWAPCHAIN_UPDATE_STATE_EXTENSION_NAME",
    "FB_TOUCH_CONTROLLER_PROXIMITY_EXTENSION_NAME",
    "FB_TOUCH_CONTROLLER_PRO_EXTENSION_NAME",
    "FB_TRIANGLE_MESH_EXTENSION_NAME",
    "FB_body_tracking",
    "FB_body_tracking_SPEC_VERSION",
    "FB_color_space",
    "FB_color_space_SPEC_VERSION",
    "FB_composition_layer_alpha_blend",
    "FB_composition_layer_alpha_blend_SPEC_VERSION",
    "FB_composition_layer_depth_test",
    "FB_composition_layer_depth_test_SPEC_VERSION",
    "FB_composition_layer_image_layout",
    "FB_composition_layer_image_layout_SPEC_VERSION",
    "FB_composition_layer_secure_content",
    "FB_composition_layer_secure_content_SPEC_VERSION",
    "FB_composition_layer_settings",
    "FB_composition_layer_settings_SPEC_VERSION",
    "FB_display_refresh_rate",
    "FB_display_refresh_rate_SPEC_VERSION",
    "FB_eye_tracking_social",
    "FB_eye_tracking_social_SPEC_VERSION",
    "FB_face_tracking",
    "FB_face_tracking2",
    "FB_face_tracking2_SPEC_VERSION",
    "FB_face_tracking_SPEC_VERSION",
    "FB_foveation",
    "FB_foveation_SPEC_VERSION",
    "FB_foveation_configuration",
    "FB_foveation_configuration_SPEC_VERSION",
    "FB_hand_tracking_aim",
    "FB_hand_tracking_aim_SPEC_VERSION",
    "FB_hand_tracking_capsules",
    "FB_hand_tracking_capsules_SPEC_VERSION",
    "FB_hand_tracking_mesh",
    "FB_hand_tracking_mesh_SPEC_VERSION",
    "FB_haptic_amplitude_envelope",
    "FB_haptic_amplitude_envelope_SPEC_VERSION",
    "FB_haptic_pcm",
    "FB_haptic_pcm_SPEC_VERSION",
    "FB_keyboard_tracking",
    "FB_keyboard_tracking_SPEC_VERSION",
    "FB_passthrough",
    "FB_passthrough_SPEC_VERSION",
    "FB_passthrough_keyboard_hands",
    "FB_passthrough_keyboard_hands_SPEC_VERSION",
    "FB_render_model",
    "FB_render_model_SPEC_VERSION",
    "FB_scene",
    "FB_scene_SPEC_VERSION",
    "FB_scene_capture",
    "FB_scene_capture_SPEC_VERSION",
    "FB_space_warp",
    "FB_space_warp_SPEC_VERSION",
    "FB_spatial_entity",
    "FB_spatial_entity_SPEC_VERSION",
    "FB_spatial_entity_container",
    "FB_spatial_entity_container_SPEC_VERSION",
    "FB_spatial_entity_query",
    "FB_spatial_entity_query_SPEC_VERSION",
    "FB_spatial_entity_sharing",
    "FB_spatial_entity_sharing_SPEC_VERSION",
    "FB_spatial_entity_storage",
    "FB_spatial_entity_storage_SPEC_VERSION",
    "FB_spatial_entity_storage_batch",
    "FB_spatial_entity_storage_batch_SPEC_VERSION",
    "FB_spatial_entity_user",
    "FB_spatial_entity_user_SPEC_VERSION",
    "FB_swapchain_update_state",
    "FB_swapchain_update_state_SPEC_VERSION",
    "FB_touch_controller_pro",
    "FB_touch_controller_pro_SPEC_VERSION",
    "FB_touch_controller_proximity",
    "FB_touch_controller_proximity_SPEC_VERSION",
    "FB_triangle_mesh",
    "FB_triangle_mesh_SPEC_VERSION",
    "FOVEATION_CENTER_SIZE_META",
    "FOVEATION_DYNAMIC_CLEAR_FOV_ENABLED_BIT_HTC",
    "FOVEATION_DYNAMIC_FOCAL_CENTER_OFFSET_ENABLED_BIT_HTC",
    "FOVEATION_DYNAMIC_LEVEL_ENABLED_BIT_HTC",
    "FOVEATION_EYE_TRACKED_STATE_VALID_BIT_META",
    "FRAME_END_INFO_PROTECTED_BIT_ML",
    "FRAME_END_INFO_VIGNETTE_BIT_ML",
    "FRAME_SYNTHESIS_INFO_REQUEST_RELAXED_FRAME_INTERVAL_BIT_EXT",
    "FRAME_SYNTHESIS_INFO_USE_2D_MOTION_VECTOR_BIT_EXT",
    "FREQUENCY_UNSPECIFIED",
    "GLOBAL_DIMMER_FRAME_END_INFO_ENABLED_BIT_ML",
    "GUID_SIZE_MSFT",
    "HAND_FOREARM_JOINT_COUNT_ULTRALEAP",
    "HAND_JOINT_COUNT_EXT",
    "HAND_TRACKING_AIM_COMPUTED_BIT_FB",
    "HAND_TRACKING_AIM_DOMINANT_HAND_BIT_FB",
    "HAND_TRACKING_AIM_INDEX_PINCHING_BIT_FB",
    "HAND_TRACKING_AIM_LITTLE_PINCHING_BIT_FB",
    "HAND_TRACKING_AIM_MENU_PRESSED_BIT_FB",
    "HAND_TRACKING_AIM_MIDDLE_PINCHING_BIT_FB",
    "HAND_TRACKING_AIM_RING_PINCHING_BIT_FB",
    "HAND_TRACKING_AIM_SYSTEM_GESTURE_BIT_FB",
    "HAND_TRACKING_AIM_VALID_BIT_FB",
    "HAND_TRACKING_CAPSULE_COUNT_FB",
    "HAND_TRACKING_CAPSULE_POINT_COUNT_FB",
    "HTCX_VIVE_TRACKER_INTERACTION_EXTENSION_NAME",
    "HTCX_vive_tracker_interaction",
    "HTCX_vive_tracker_interaction_SPEC_VERSION",
    "HTC_ANCHOR_EXTENSION_NAME",
    "HTC_BODY_TRACKING_EXTENSION_NAME",
    "HTC_FACIAL_TRACKING_EXTENSION_NAME",
    "HTC_FOVEATION_EXTENSION_NAME",
    "HTC_HAND_INTERACTION_EXTENSION_NAME",
    "HTC_PASSTHROUGH_EXTENSION_NAME",
    "HTC_VIVE_COSMOS_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "HTC_VIVE_FOCUS3_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "HTC_VIVE_WRIST_TRACKER_INTERACTION_EXTENSION_NAME",
    "HTC_anchor",
    "HTC_anchor_SPEC_VERSION",
    "HTC_body_tracking",
    "HTC_body_tracking_SPEC_VERSION",
    "HTC_facial_tracking",
    "HTC_facial_tracking_SPEC_VERSION",
    "HTC_foveation",
    "HTC_foveation_SPEC_VERSION",
    "HTC_hand_interaction",
    "HTC_hand_interaction_SPEC_VERSION",
    "HTC_passthrough",
    "HTC_passthrough_SPEC_VERSION",
    "HTC_vive_cosmos_controller_interaction",
    "HTC_vive_cosmos_controller_interaction_SPEC_VERSION",
    "HTC_vive_focus3_controller_interaction",
    "HTC_vive_focus3_controller_interaction_SPEC_VERSION",
    "HTC_vive_wrist_tracker_interaction",
    "HTC_vive_wrist_tracker_interaction_SPEC_VERSION",
    "HUAWEI_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "HUAWEI_controller_interaction",
    "HUAWEI_controller_interaction_SPEC_VERSION",
    "INFINITE_DURATION",
    "INPUT_SOURCE_LOCALIZED_NAME_COMPONENT_BIT",
    "INPUT_SOURCE_LOCALIZED_NAME_INTERACTION_PROFILE_BIT",
    "INPUT_SOURCE_LOCALIZED_NAME_USER_PATH_BIT",
    "KEYBOARD_TRACKING_CONNECTED_BIT_FB",
    "KEYBOARD_TRACKING_EXISTS_BIT_FB",
    "KEYBOARD_TRACKING_LOCAL_BIT_FB",
    "KEYBOARD_TRACKING_QUERY_LOCAL_BIT_FB",
    "KEYBOARD_TRACKING_QUERY_REMOTE_BIT_FB",
    "KEYBOARD_TRACKING_REMOTE_BIT_FB",
    "KHR_BINDING_MODIFICATION_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_COLOR_SCALE_BIAS_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_CUBE_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_CYLINDER_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_DEPTH_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_EQUIRECT2_EXTENSION_NAME",
    "KHR_COMPOSITION_LAYER_EQUIRECT_EXTENSION_NAME",
    "KHR_EXTENDED_STRUCT_NAME_LENGTHS_EXTENSION_NAME",
    "KHR_LOADER_INIT_EXTENSION_NAME",
    "KHR_LOCATE_SPACES_EXTENSION_NAME",
    "KHR_MAINTENANCE1_EXTENSION_NAME",
    "KHR_SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_EXTENSION_NAME",
    "KHR_VISIBILITY_MASK_EXTENSION_NAME",
    "KHR_binding_modification",
    "KHR_binding_modification_SPEC_VERSION",
    "KHR_composition_layer_color_scale_bias",
    "KHR_composition_layer_color_scale_bias_SPEC_VERSION",
    "KHR_composition_layer_cube",
    "KHR_composition_layer_cube_SPEC_VERSION",
    "KHR_composition_layer_cylinder",
    "KHR_composition_layer_cylinder_SPEC_VERSION",
    "KHR_composition_layer_depth",
    "KHR_composition_layer_depth_SPEC_VERSION",
    "KHR_composition_layer_equirect",
    "KHR_composition_layer_equirect2",
    "KHR_composition_layer_equirect2_SPEC_VERSION",
    "KHR_composition_layer_equirect_SPEC_VERSION",
    "KHR_extended_struct_name_lengths",
    "KHR_extended_struct_name_lengths_SPEC_VERSION",
    "KHR_loader_init",
    "KHR_loader_init_SPEC_VERSION",
    "KHR_locate_spaces",
    "KHR_locate_spaces_SPEC_VERSION",
    "KHR_maintenance1",
    "KHR_maintenance1_SPEC_VERSION",
    "KHR_swapchain_usage_input_attachment_bit",
    "KHR_swapchain_usage_input_attachment_bit_SPEC_VERSION",
    "KHR_visibility_mask",
    "KHR_visibility_mask_SPEC_VERSION",
    "LOCALIZATION_MAP_ERROR_EXCESSIVE_MOTION_BIT_ML",
    "LOCALIZATION_MAP_ERROR_HEADPOSE_BIT_ML",
    "LOCALIZATION_MAP_ERROR_LOW_FEATURE_COUNT_BIT_ML",
    "LOCALIZATION_MAP_ERROR_LOW_LIGHT_BIT_ML",
    "LOCALIZATION_MAP_ERROR_OUT_OF_MAPPED_AREA_BIT_ML",
    "LOCALIZATION_MAP_ERROR_UNKNOWN_BIT_ML",
    "LOGITECH_MX_INK_STYLUS_INTERACTION_EXTENSION_NAME",
    "LOGITECH_mx_ink_stylus_interaction",
    "LOGITECH_mx_ink_stylus_interaction_SPEC_VERSION",
    "MAX_ACTION_NAME_SIZE",
    "MAX_ACTION_SET_NAME_SIZE",
    "MAX_API_LAYER_DESCRIPTION_SIZE",
    "MAX_API_LAYER_NAME_SIZE",
    "MAX_APPLICATION_NAME_SIZE",
    "MAX_COLOCATION_DISCOVERY_BUFFER_SIZE_META",
    "MAX_CONTROLLER_MODEL_NODE_NAME_SIZE_MSFT",
    "MAX_ENGINE_NAME_SIZE",
    "MAX_EXTENSION_NAME_SIZE",
    "MAX_EXTERNAL_CAMERA_NAME_SIZE_OCULUS",
    "MAX_HAPTIC_AMPLITUDE_ENVELOPE_SAMPLES_FB",
    "MAX_HAPTIC_PCM_BUFFER_SIZE_FB",
    "MAX_KEYBOARD_TRACKING_NAME_SIZE_FB",
    "MAX_LOCALIZATION_MAP_NAME_LENGTH_ML",
    "MAX_LOCALIZED_ACTION_NAME_SIZE",
    "MAX_LOCALIZED_ACTION_SET_NAME_SIZE",
    "MAX_PATH_LENGTH",
    "MAX_RENDER_MODEL_ASSET_NODE_NAME_SIZE_EXT",
    "MAX_RENDER_MODEL_NAME_SIZE_FB",
    "MAX_RESULT_STRING_SIZE",
    "MAX_RUNTIME_NAME_SIZE",
    "MAX_SPACES_PER_SHARE_REQUEST_META",
    "MAX_SPATIAL_ANCHOR_NAME_SIZE_HTC",
    "MAX_SPATIAL_ANCHOR_NAME_SIZE_MSFT",
    "MAX_STRUCTURE_NAME_SIZE",
    "MAX_STRUCTURE_NAME_SIZE_EXTENDED_KHR",
    "MAX_SYSTEM_NAME_SIZE",
    "MAX_VIRTUAL_KEYBOARD_COMMIT_TEXT_SIZE_META",
    "META_AUTOMATIC_LAYER_FILTER_EXTENSION_NAME",
    "META_BODY_TRACKING_FULL_BODY_EXTENSION_NAME",
    "META_COLOCATION_DISCOVERY_EXTENSION_NAME",
    "META_DETACHED_CONTROLLERS_EXTENSION_NAME",
    "META_ENVIRONMENT_DEPTH_EXTENSION_NAME",
    "META_FOVEATION_EYE_TRACKED_EXTENSION_NAME",
    "META_HAND_TRACKING_MICROGESTURES_EXTENSION_NAME",
    "META_HEADSET_ID_EXTENSION_NAME",
    "META_LOCAL_DIMMING_EXTENSION_NAME",
    "META_PASSTHROUGH_COLOR_LUT_EXTENSION_NAME",
    "META_PASSTHROUGH_LAYER_RESUMED_EVENT_EXTENSION_NAME",
    "META_PASSTHROUGH_PREFERENCES_EXTENSION_NAME",
    "META_PERFORMANCE_METRICS_EXTENSION_NAME",
    "META_RECOMMENDED_LAYER_RESOLUTION_EXTENSION_NAME",
    "META_SIMULTANEOUS_HANDS_AND_CONTROLLERS_EXTENSION_NAME",
    "META_SPATIAL_ENTITY_GROUP_SHARING_EXTENSION_NAME",
    "META_SPATIAL_ENTITY_MESH_EXTENSION_NAME",
    "META_SPATIAL_ENTITY_SHARING_EXTENSION_NAME",
    "META_TOUCH_CONTROLLER_PLUS_EXTENSION_NAME",
    "META_VIRTUAL_KEYBOARD_EXTENSION_NAME",
    "META_automatic_layer_filter",
    "META_automatic_layer_filter_SPEC_VERSION",
    "META_body_tracking_full_body",
    "META_body_tracking_full_body_SPEC_VERSION",
    "META_colocation_discovery",
    "META_colocation_discovery_SPEC_VERSION",
    "META_detached_controllers",
    "META_detached_controllers_SPEC_VERSION",
    "META_environment_depth",
    "META_environment_depth_SPEC_VERSION",
    "META_foveation_eye_tracked",
    "META_foveation_eye_tracked_SPEC_VERSION",
    "META_hand_tracking_microgestures",
    "META_hand_tracking_microgestures_SPEC_VERSION",
    "META_headset_id",
    "META_headset_id_SPEC_VERSION",
    "META_local_dimming",
    "META_local_dimming_SPEC_VERSION",
    "META_passthrough_color_lut",
    "META_passthrough_color_lut_SPEC_VERSION",
    "META_passthrough_layer_resumed_event",
    "META_passthrough_layer_resumed_event_SPEC_VERSION",
    "META_passthrough_preferences",
    "META_passthrough_preferences_SPEC_VERSION",
    "META_performance_metrics",
    "META_performance_metrics_SPEC_VERSION",
    "META_recommended_layer_resolution",
    "META_recommended_layer_resolution_SPEC_VERSION",
    "META_simultaneous_hands_and_controllers",
    "META_simultaneous_hands_and_controllers_SPEC_VERSION",
    "META_spatial_entity_group_sharing",
    "META_spatial_entity_group_sharing_SPEC_VERSION",
    "META_spatial_entity_mesh",
    "META_spatial_entity_mesh_SPEC_VERSION",
    "META_spatial_entity_sharing",
    "META_spatial_entity_sharing_SPEC_VERSION",
    "META_touch_controller_plus",
    "META_touch_controller_plus_SPEC_VERSION",
    "META_virtual_keyboard",
    "META_virtual_keyboard_SPEC_VERSION",
    "MIN_COMPOSITION_LAYERS_SUPPORTED",
    "MIN_HAPTIC_DURATION",
    "ML_FACIAL_EXPRESSION_EXTENSION_NAME",
    "ML_FRAME_END_INFO_EXTENSION_NAME",
    "ML_GLOBAL_DIMMER_EXTENSION_NAME",
    "ML_LOCALIZATION_MAP_EXTENSION_NAME",
    "ML_MARKER_UNDERSTANDING_EXTENSION_NAME",
    "ML_ML2_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "ML_SPATIAL_ANCHORS_EXTENSION_NAME",
    "ML_SPATIAL_ANCHORS_STORAGE_EXTENSION_NAME",
    "ML_SYSTEM_NOTIFICATIONS_EXTENSION_NAME",
    "ML_USER_CALIBRATION_EXTENSION_NAME",
    "ML_VIEW_CONFIGURATION_DEPTH_RANGE_CHANGE_EXTENSION_NAME",
    "ML_WORLD_MESH_DETECTION_EXTENSION_NAME",
    "ML_facial_expression",
    "ML_facial_expression_SPEC_VERSION",
    "ML_frame_end_info",
    "ML_frame_end_info_SPEC_VERSION",
    "ML_global_dimmer",
    "ML_global_dimmer_SPEC_VERSION",
    "ML_localization_map",
    "ML_localization_map_SPEC_VERSION",
    "ML_marker_understanding",
    "ML_marker_understanding_SPEC_VERSION",
    "ML_ml2_controller_interaction",
    "ML_ml2_controller_interaction_SPEC_VERSION",
    "ML_spatial_anchors",
    "ML_spatial_anchors_SPEC_VERSION",
    "ML_spatial_anchors_storage",
    "ML_spatial_anchors_storage_SPEC_VERSION",
    "ML_system_notifications",
    "ML_system_notifications_SPEC_VERSION",
    "ML_user_calibration",
    "ML_user_calibration_SPEC_VERSION",
    "ML_view_configuration_depth_range_change",
    "ML_view_configuration_depth_range_change_SPEC_VERSION",
    "ML_world_mesh_detection",
    "ML_world_mesh_detection_SPEC_VERSION",
    "MNDX_FORCE_FEEDBACK_CURL_EXTENSION_NAME",
    "MNDX_force_feedback_curl",
    "MNDX_force_feedback_curl_SPEC_VERSION",
    "MND_HEADLESS_EXTENSION_NAME",
    "MND_SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_EXTENSION_NAME",
    "MND_headless",
    "MND_headless_SPEC_VERSION",
    "MND_swapchain_usage_input_attachment_bit",
    "MND_swapchain_usage_input_attachment_bit_SPEC_VERSION",
    "MSFT_COMPOSITION_LAYER_REPROJECTION_EXTENSION_NAME",
    "MSFT_CONTROLLER_MODEL_EXTENSION_NAME",
    "MSFT_FIRST_PERSON_OBSERVER_EXTENSION_NAME",
    "MSFT_HAND_INTERACTION_EXTENSION_NAME",
    "MSFT_HAND_TRACKING_MESH_EXTENSION_NAME",
    "MSFT_SCENE_MARKER_EXTENSION_NAME",
    "MSFT_SCENE_UNDERSTANDING_EXTENSION_NAME",
    "MSFT_SCENE_UNDERSTANDING_SERIALIZATION_EXTENSION_NAME",
    "MSFT_SECONDARY_VIEW_CONFIGURATION_EXTENSION_NAME",
    "MSFT_SPATIAL_ANCHOR_EXTENSION_NAME",
    "MSFT_SPATIAL_ANCHOR_PERSISTENCE_EXTENSION_NAME",
    "MSFT_SPATIAL_GRAPH_BRIDGE_EXTENSION_NAME",
    "MSFT_UNBOUNDED_REFERENCE_SPACE_EXTENSION_NAME",
    "MSFT_composition_layer_reprojection",
    "MSFT_composition_layer_reprojection_SPEC_VERSION",
    "MSFT_controller_model",
    "MSFT_controller_model_SPEC_VERSION",
    "MSFT_first_person_observer",
    "MSFT_first_person_observer_SPEC_VERSION",
    "MSFT_hand_interaction",
    "MSFT_hand_interaction_SPEC_VERSION",
    "MSFT_hand_tracking_mesh",
    "MSFT_hand_tracking_mesh_SPEC_VERSION",
    "MSFT_scene_marker",
    "MSFT_scene_marker_SPEC_VERSION",
    "MSFT_scene_understanding",
    "MSFT_scene_understanding_SPEC_VERSION",
    "MSFT_scene_understanding_serialization",
    "MSFT_scene_understanding_serialization_SPEC_VERSION",
    "MSFT_secondary_view_configuration",
    "MSFT_secondary_view_configuration_SPEC_VERSION",
    "MSFT_spatial_anchor",
    "MSFT_spatial_anchor_SPEC_VERSION",
    "MSFT_spatial_anchor_persistence",
    "MSFT_spatial_anchor_persistence_SPEC_VERSION",
    "MSFT_spatial_graph_bridge",
    "MSFT_spatial_graph_bridge_SPEC_VERSION",
    "MSFT_unbounded_reference_space",
    "MSFT_unbounded_reference_space_SPEC_VERSION",
    "NO_DURATION",
    "NULL_CONTROLLER_MODEL_KEY_MSFT",
    "NULL_FUTURE_EXT",
    "NULL_HANDLE",
    "NULL_PATH",
    "NULL_RENDER_MODEL_ID_EXT",
    "NULL_RENDER_MODEL_KEY_FB",
    "NULL_SPATIAL_BUFFER_ID_EXT",
    "NULL_SPATIAL_ENTITY_ID_EXT",
    "NULL_SYSTEM_ID",
    "OCULUS_ANDROID_SESSION_STATE_ENABLE_EXTENSION_NAME",
    "OCULUS_EXTERNAL_CAMERA_EXTENSION_NAME",
    "OCULUS_android_session_state_enable",
    "OCULUS_android_session_state_enable_SPEC_VERSION",
    "OCULUS_external_camera",
    "OCULUS_external_camera_SPEC_VERSION",
    "OPPO_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "OPPO_controller_interaction",
    "OPPO_controller_interaction_SPEC_VERSION",
    "OVERLAY_MAIN_SESSION_ENABLED_COMPOSITION_LAYER_INFO_DEPTH_BIT_EXTX",
    "PASSTHROUGH_CAPABILITY_BIT_FB",
    "PASSTHROUGH_CAPABILITY_COLOR_BIT_FB",
    "PASSTHROUGH_CAPABILITY_LAYER_DEPTH_BIT_FB",
    "PASSTHROUGH_COLOR_MAP_MONO_SIZE_FB",
    "PASSTHROUGH_IS_RUNNING_AT_CREATION_BIT_FB",
    "PASSTHROUGH_LAYER_DEPTH_BIT_FB",
    "PASSTHROUGH_PREFERENCE_DEFAULT_TO_ACTIVE_BIT_META",
    "PASSTHROUGH_STATE_CHANGED_NON_RECOVERABLE_ERROR_BIT_FB",
    "PASSTHROUGH_STATE_CHANGED_RECOVERABLE_ERROR_BIT_FB",
    "PASSTHROUGH_STATE_CHANGED_REINIT_REQUIRED_BIT_FB",
    "PASSTHROUGH_STATE_CHANGED_RESTORED_ERROR_BIT_FB",
    "PERFORMANCE_METRICS_COUNTER_ANY_VALUE_VALID_BIT_META",
    "PERFORMANCE_METRICS_COUNTER_FLOAT_VALUE_VALID_BIT_META",
    "PERFORMANCE_METRICS_COUNTER_UINT_VALUE_VALID_BIT_META",
    "PLANE_DETECTION_CAPABILITY_ORIENTATION_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_PLANE_DETECTION_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_PLANE_HOLES_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_SEMANTIC_CEILING_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_SEMANTIC_FLOOR_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_SEMANTIC_PLATFORM_BIT_EXT",
    "PLANE_DETECTION_CAPABILITY_SEMANTIC_WALL_BIT_EXT",
    "PLANE_DETECTOR_ENABLE_CONTOUR_BIT_EXT",
    "QCOM_TRACKING_OPTIMIZATION_SETTINGS_EXTENSION_NAME",
    "QCOM_tracking_optimization_settings",
    "QCOM_tracking_optimization_settings_SPEC_VERSION",
    "RENDER_MODEL_SUPPORTS_GLTF_2_0_SUBSET_1_BIT_FB",
    "RENDER_MODEL_SUPPORTS_GLTF_2_0_SUBSET_2_BIT_FB",
    "SEMANTIC_LABELS_SUPPORT_ACCEPT_DESK_TO_TABLE_MIGRATION_BIT_FB",
    "SEMANTIC_LABELS_SUPPORT_ACCEPT_INVISIBLE_WALL_FACE_BIT_FB",
    "SEMANTIC_LABELS_SUPPORT_MULTIPLE_SEMANTIC_LABELS_BIT_FB",
    "SPACE_LOCATION_ORIENTATION_TRACKED_BIT",
    "SPACE_LOCATION_ORIENTATION_VALID_BIT",
    "SPACE_LOCATION_POSITION_TRACKED_BIT",
    "SPACE_LOCATION_POSITION_VALID_BIT",
    "SPACE_VELOCITY_ANGULAR_VALID_BIT",
    "SPACE_VELOCITY_LINEAR_VALID_BIT",
    "SPATIAL_MESH_CONFIG_ALIGN_SEMANTIC_WITH_VERTEX_BIT_BD",
    "SPATIAL_MESH_CONFIG_SEMANTIC_BIT_BD",
    "SWAPCHAIN_CREATE_FOVEATION_FRAGMENT_DENSITY_MAP_BIT_FB",
    "SWAPCHAIN_CREATE_FOVEATION_SCALED_BIN_BIT_FB",
    "SWAPCHAIN_CREATE_PROTECTED_CONTENT_BIT",
    "SWAPCHAIN_CREATE_STATIC_IMAGE_BIT",
    "SWAPCHAIN_USAGE_COLOR_ATTACHMENT_BIT",
    "SWAPCHAIN_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT",
    "SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_KHR",
    "SWAPCHAIN_USAGE_INPUT_ATTACHMENT_BIT_MND",
    "SWAPCHAIN_USAGE_MUTABLE_FORMAT_BIT",
    "SWAPCHAIN_USAGE_SAMPLED_BIT",
    "SWAPCHAIN_USAGE_TRANSFER_DST_BIT",
    "SWAPCHAIN_USAGE_TRANSFER_SRC_BIT",
    "SWAPCHAIN_USAGE_UNORDERED_ACCESS_BIT",
    "TRIANGLE_MESH_MUTABLE_BIT_FB",
    "TRUE",
    "ULTRALEAP_HAND_TRACKING_FOREARM_EXTENSION_NAME",
    "ULTRALEAP_hand_tracking_forearm",
    "ULTRALEAP_hand_tracking_forearm_SPEC_VERSION",
    "UUID_SIZE",
    "UUID_SIZE_EXT",
    "VALVE_ANALOG_THRESHOLD_EXTENSION_NAME",
    "VALVE_analog_threshold",
    "VALVE_analog_threshold_SPEC_VERSION",
    "VARJO_COMPOSITION_LAYER_DEPTH_TEST_EXTENSION_NAME",
    "VARJO_ENVIRONMENT_DEPTH_ESTIMATION_EXTENSION_NAME",
    "VARJO_FOVEATED_RENDERING_EXTENSION_NAME",
    "VARJO_MARKER_TRACKING_EXTENSION_NAME",
    "VARJO_QUAD_VIEWS_EXTENSION_NAME",
    "VARJO_VIEW_OFFSET_EXTENSION_NAME",
    "VARJO_XR4_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "VARJO_composition_layer_depth_test",
    "VARJO_composition_layer_depth_test_SPEC_VERSION",
    "VARJO_environment_depth_estimation",
    "VARJO_environment_depth_estimation_SPEC_VERSION",
    "VARJO_foveated_rendering",
    "VARJO_foveated_rendering_SPEC_VERSION",
    "VARJO_marker_tracking",
    "VARJO_marker_tracking_SPEC_VERSION",
    "VARJO_quad_views",
    "VARJO_quad_views_SPEC_VERSION",
    "VARJO_view_offset",
    "VARJO_view_offset_SPEC_VERSION",
    "VARJO_xr4_controller_interaction",
    "VARJO_xr4_controller_interaction_SPEC_VERSION",
    "VERSION_1_0",
    "VERSION_1_1",
    "VIEW_STATE_ORIENTATION_TRACKED_BIT",
    "VIEW_STATE_ORIENTATION_VALID_BIT",
    "VIEW_STATE_POSITION_TRACKED_BIT",
    "VIEW_STATE_POSITION_VALID_BIT",
    "VIRTUAL_KEYBOARD_INPUT_STATE_PRESSED_BIT_META",
    "WORLD_MESH_DETECTOR_COMPUTE_CONFIDENCE_BIT_ML",
    "WORLD_MESH_DETECTOR_COMPUTE_NORMALS_BIT_ML",
    "WORLD_MESH_DETECTOR_INDEX_ORDER_CW_BIT_ML",
    "WORLD_MESH_DETECTOR_PLANARIZE_BIT_ML",
    "WORLD_MESH_DETECTOR_POINT_CLOUD_BIT_ML",
    "WORLD_MESH_DETECTOR_REMOVE_MESH_SKIRT_BIT_ML",
    "YVR_CONTROLLER_INTERACTION_EXTENSION_NAME",
    "YVR_controller_interaction",
    "YVR_controller_interaction_SPEC_VERSION",
]



import unittest

import xr


class TestConstants(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_constants(self):
        # Ensure presence of certain constants
        xr.NO_DURATION
        xr.MIN_HAPTIC_DURATION  # Constant missing in 1.0.2203


if __name__ == '__main__':
    unittest.main()



import unittest

import xr


class TestPrintObject(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_print_object(self):
        apl = xr.ApiLayerProperties()
        print(apl)


if __name__ == '__main__':
    unittest.main()



import unittest

import xr


class TestCreateInfo(unittest.TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_default_constructible(self):
        xr.ActionCreateInfo()
        xr.ActionSetCreateInfo()
        xr.ActionSpaceCreateInfo()
        xr.InstanceCreateInfo()
        xr.ReferenceSpaceCreateInfo()
        xr.SessionCreateInfo()
        xr.SwapchainCreateInfo()

    def test_default_constructible2(self):
        try:
            xr.create_instance()
        except (xr.RuntimeUnavailableError, xr.RuntimeFailureError):
            # Pass test on machine with no OpenXR runtime running.
            # But *not* TypeError
            pass


if __name__ == '__main__':
    unittest.main()



"""
Tests for version numbers

Based on tests at https://github.com/KhronosGroup/OpenXR-Hpp/blob/master/tests/version.cpp
"""

import unittest

import xr


class TestFlags(unittest.TestCase):
    def setUp(self):
        self.version_123 = 0x0001000200000003
        self.version_321 = 0x0003000200000001

    def tearDown(self):
        pass

    def test_version(self):
        v = xr.Version()
        self.assertEqual(0, v.major)
        self.assertEqual(0, v.minor)
        self.assertEqual(0, v.patch)
        #
        v = xr.Version(self.version_123)
        self.assertEqual(1, v.major)
        self.assertEqual(2, v.minor)
        self.assertEqual(3, v.patch)
        #
        v = xr.Version(self.version_321)
        self.assertEqual(3, v.major)
        self.assertEqual(2, v.minor)
        self.assertEqual(1, v.patch)
        self.assertEqual(self.version_123, xr.Version(1, 2, 3).number())


if __name__ == '__main__':
    unittest.main()



import unittest

import xr


class TestVector3f(unittest.TestCase):
    def setUp(self):
        self.p = xr.Posef()

    def tearDown(self):
        pass

    def test_posef(self):
        self.assertEqual(1, self.p.orientation.w)


if __name__ == '__main__':
    unittest.main()
